"""Test that disabling too-many-lines on any line works."""



# pylint: disable=too-many-lines
__revision__ = 0




































































































































































































































































































ZERFZAER = 3














































































































































































































































































































































































































































































































































































































































































































































HEHEHE = 2
